@@ -1,11 +1,11 @@
-# Copyright Cartopy Contributors
+# Copyright Crown and Cartopy Contributors
 #
-# This file is part of Cartopy and is released under the LGPL license.
-# See COPYING and COPYING.LESSER in the root of the repository for full
-# licensing details.
+# This file is part of Cartopy and is released under the BSD 3-clause license.
+# See LICENSE in the root of the repository for full licensing details.
 
 """
-Combine the shapefile access of pyshp with the
+This module provides a basic interface for accessing shapefiles.
+Combine the shapefile access of pyshp or fiona with the
 geometry representation of shapely:
 
     >>> import cartopy.io.shapereader as shapereader
@@ -123,7 +123,9 @@ class FionaRecord(Record):
 
 class BasicReader:
     """
-    Provide an interface for accessing the contents of a shapefile.
+    Provide an interface for accessing the contents of a shapefile with the
+    Python Shapefile Library (PyShp). See the PyShp
+    `Readme <https://pypi.org/project/pyshp/>`_ for more information.
 
     The primary methods used on a BasicReader instance are
     :meth:`~cartopy.io.shapereader.BasicReader.records` and
@@ -131,9 +133,10 @@ class BasicReader:
 
     """
 
-    def __init__(self, filename, bbox=None):
+    def __init__(self, filename, bbox=None, **kwargs):
         # Validate the filename/shapefile
-        self._reader = reader = shapefile.Reader(filename)
+        self._reader = reader = shapefile.Reader(filename, **kwargs)
+        self._bbox = bbox
         if reader.shp is None or reader.shx is None or reader.dbf is None:
             raise ValueError("Incomplete shapefile definition "
                              "in '%s'." % filename)
@@ -158,7 +161,7 @@ class BasicReader:
         :meth:`~Record.geometry` method.
 
         """
-        for shape in self._reader.iterShapes():
+        for shape in self._reader.iterShapes(bbox=self._bbox):
             # Skip the shape that can not be represented as geometry.
             if shape.shapeType != shapefile.NULL:
                 yield sgeom.shape(shape)
@@ -168,9 +171,10 @@ class BasicReader:
         Return an iterator of :class:`~Record` instances.
 
         """
+
         # Ignore the "DeletionFlag" field which always comes first
         fields = self._reader.fields[1:]
-        for shape_record in self._reader.iterShapeRecords():
+        for shape_record in self._reader.iterShapeRecords(bbox=self._bbox):
             attributes = shape_record.record.as_dict()
             yield Record(shape_record.shape, attributes, fields)
 
@@ -178,7 +182,10 @@ class BasicReader:
 class FionaReader:
     """
     Provides an interface for accessing the contents of a shapefile
-    with the fiona library, which has a much faster reader than pyshp.
+    with the fiona library, which has a much faster reader than PyShp. See
+    `fiona.open
+    <https://fiona.readthedocs.io/en/latest/fiona.html#fiona.open>`_
+    for additional information on supported kwargs.
 
     The primary methods used on a FionaReader instance are
     :meth:`~cartopy.io.shapereader.FionaReader.records` and
@@ -186,10 +193,10 @@ class FionaReader:
 
     """
 
-    def __init__(self, filename, bbox=None):
+    def __init__(self, filename, bbox=None, **kwargs):
         self._data = []
 
-        with fiona.open(filename) as f:
+        with fiona.open(filename, **kwargs) as f:
             if bbox is not None:
                 assert len(bbox) == 4
                 features = f.filter(bbox=bbox)
@@ -253,10 +260,19 @@ class FionaReader:
                                item.items() if key != 'geometry'})
 
 
-if _HAS_FIONA:
-    Reader = FionaReader
-else:
-    Reader = BasicReader
+Reader = FionaReader if _HAS_FIONA else BasicReader
+"""
+Alias of the default available shapereader interface.
+
+Will either be :class:`~cartopy.io.shapereader.FionaReader` (if fiona
+installed) or :class:`~cartopy.io.shapereader.BasicReader`
+(based on PyShp). Note that FionaReader has greater speed and additional
+functionality, including attempting to auto-detect source encoding and
+support for different format drivers. Both libraries support the 'encoding'
+and 'bbox' keyword arguments. If specific functionality is needed,
+BasicReader and FionaReader instances can also be created directly.
+
+"""
 
 
 def natural_earth(resolution='110m', category='physical', name='coastline'):
@@ -266,8 +282,8 @@ def natural_earth(resolution='110m', category='physical', name='coastline'):
 
     To identify valid components for this function, either browse
     NaturalEarthData.com, or if you know what you are looking for, go to
-    https://github.com/nvkelso/natural-earth-vector/tree/master/zips to
-    see the actual files which will be downloaded.
+    https://github.com/nvkelso/natural-earth-vector/ to see the actual
+    files which will be downloaded.
 
     Note
     ----
