@@ -1,11 +1,12 @@
-# Copyright Cartopy Contributors
+# Copyright Crown and Cartopy Contributors
 #
-# This file is part of Cartopy and is released under the LGPL license.
-# See COPYING and COPYING.LESSER in the root of the repository for full
-# licensing details.
+# This file is part of Cartopy and is released under the BSD 3-clause license.
+# See LICENSE in the root of the repository for full licensing details.
 
 """
-This module defines the :class:`GeoAxes` class, for use with matplotlib.
+This module defines the :class:`cartopy.mpl.geoaxes.GeoAxes` class, an extension of
+matplotlib which adds a `transform` keyword argument to many plotting methods to enable
+geographic projections and boundary wrapping to occur on the axes.
 
 When a Matplotlib figure contains a GeoAxes the plotting commands can transform
 plot results from source coordinates to the GeoAxes' target projection.
@@ -32,12 +33,12 @@ import matplotlib.spines as mspines
 import matplotlib.transforms as mtransforms
 import numpy as np
 import numpy.ma as ma
-import packaging
 import shapely.geometry as sgeom
 
 from cartopy import config
 import cartopy.crs as ccrs
 import cartopy.feature
+from cartopy.mpl import _MPL_38
 import cartopy.mpl.contour
 import cartopy.mpl.feature_artist as feature_artist
 import cartopy.mpl.geocollection
@@ -45,10 +46,6 @@ import cartopy.mpl.patch as cpatch
 from cartopy.mpl.slippy_image_artist import SlippyImageArtist
 
 
-_MPL_VERSION = packaging.version.parse(mpl.__version__)
-assert _MPL_VERSION.release >= (3, 4), \
-    'Cartopy is only supported with Matplotlib 3.4 or greater.'
-
 # A nested mapping from path, source CRS, and target projection to the
 # resulting transformed paths:
 #     {path: {(source_crs, target_projection): list_of_paths}}
@@ -64,7 +61,6 @@ _BACKG_IMG_CACHE = {}
 # CARTOPY_USER_BACKGROUNDS environment variable.
 _USER_BG_IMGS = {}
 
-
 # XXX call this InterCRSTransform
 class InterProjectionTransform(mtransforms.Transform):
     """
@@ -175,12 +171,7 @@ class InterProjectionTransform(mtransforms.Transform):
             return mpath.Path(self.transform(src_path.vertices))
 
         transformed_geoms = []
-        # Check whether this transform has the "force_path_ccw" attribute set.
-        # This is a cartopy extension to the Transform API to allow finer
-        # control of Path orientation handling (Path ordering is not important
-        # in matplotlib, but is in Cartopy).
-        geoms = cpatch.path_to_geos(src_path,
-                                    getattr(self, 'force_path_ccw', False))
+        geoms = cpatch.path_to_geos(src_path)
 
         for geom in geoms:
             proj_geom = self.target_projection.project_geometry(
@@ -237,17 +228,15 @@ class _ViewClippedPathPatch(mpatches.PathPatch):
         super().set_transform(self._trans_wrap)
 
     def set_boundary(self, path, transform):
-        self._original_path = path
+        self._original_path = cpatch._ensure_path_closed(path)
         self.set_transform(transform)
         self.stale = True
 
-    # Can remove and use matplotlib's once we support only >= 3.2
-    def set_path(self, path):
-        self._path = path
-
     def _adjust_location(self):
         if self.stale:
-            self.set_path(self._original_path.clip_to_bbox(self.axes.viewLim))
+            self.set_path(
+                cpatch._ensure_path_closed(
+                    self._original_path.clip_to_bbox(self.axes.viewLim)))
             # Some places in matplotlib's transform stack cache the actual
             # path so we trigger an update by invalidating the transform.
             self._trans_wrap.invalidate()
@@ -265,14 +254,16 @@ class GeoSpine(mspines.Spine):
         super().__init__(axes, 'geo', self._original_path, **kwargs)
 
     def set_boundary(self, path, transform):
-        self._original_path = path
+        # Make sure path is closed (required by "Path.clip_to_bbox")
+        self._original_path = cpatch._ensure_path_closed(path)
         self.set_transform(transform)
         self.stale = True
 
     def _adjust_location(self):
         if self.stale:
-            self._path = self._original_path.clip_to_bbox(self.axes.viewLim)
-            self._path = mpath.Path(self._path.vertices, closed=True)
+            self._path = cpatch._ensure_path_closed(
+                self._original_path.clip_to_bbox(self.axes.viewLim)
+                )
 
     def get_window_extent(self, renderer=None):
         # make sure the location is updated so that transforms etc are
@@ -414,7 +405,6 @@ class GeoAxes(matplotlib.axes.Axes):
         self.projection = projection
 
         super().__init__(*args, **kwargs)
-        self._gridliners = []
         self.img_factories = []
         self._done_img_factory = False
 
@@ -476,7 +466,7 @@ class GeoAxes(matplotlib.axes.Axes):
                                self.get_autoscaley_on())
             yield
 
-    def _draw_preprocess(self, renderer):
+    def _draw_preprocess(self):
         """
         Perform pre-processing steps shared between :func:`GeoAxes.draw`
         and :func:`GeoAxes.get_tightbbox`.
@@ -486,24 +476,24 @@ class GeoAxes(matplotlib.axes.Axes):
         if self.get_autoscale_on() and self.ignore_existing_data_limits:
             self.autoscale_view()
 
-        # Adjust location of background patch so that new gridlines below are
-        # clipped correctly.
+        # apply_aspect may change the x or y data limits, so must be called
+        # before the patch is updated.
+        self.apply_aspect()
+
+        # Adjust location of background patch so that new gridlines generated
+        # by `draw` or `get_tightbbox` are positioned and clipped correctly.
         self.patch._adjust_location()
 
-        self.apply_aspect()
-        for gl in self._gridliners:
-            gl._draw_gridliner(renderer=renderer)
-
-    def get_tightbbox(self, renderer, *args, **kwargs):
+    def get_tightbbox(self, renderer=None, *args, **kwargs):
         """
         Extend the standard behaviour of
         :func:`matplotlib.axes.Axes.get_tightbbox`.
 
-        Adjust the axes aspect ratio, background patch location, and add
-        gridliners before calculating the tight bounding box.
+        Adjust the axes aspect ratio and background patch location before
+        calculating the tight bounding box.
         """
         # Shared processing steps
-        self._draw_preprocess(renderer)
+        self._draw_preprocess()
 
         return super().get_tightbbox(renderer, *args, **kwargs)
 
@@ -512,12 +502,11 @@ class GeoAxes(matplotlib.axes.Axes):
         """
         Extend the standard behaviour of :func:`matplotlib.axes.Axes.draw`.
 
-        Draw grid lines and image factory results before invoking standard
-        Matplotlib drawing. A global range is used if no limits have yet
-        been set.
+        Draw image factory results before invoking standard Matplotlib drawing.
+        A global range is used if no limits have yet been set.
         """
         # Shared processing steps
-        self._draw_preprocess(renderer)
+        self._draw_preprocess()
 
         # XXX This interface needs a tidy up:
         #       image drawing on pan/zoom;
@@ -536,21 +525,24 @@ class GeoAxes(matplotlib.axes.Axes):
 
     def _update_title_position(self, renderer):
         super()._update_title_position(renderer)
-        if not self._gridliners:
-            return
 
         if self._autotitlepos is not None and not self._autotitlepos:
             return
 
+        from cartopy.mpl.gridliner import Gridliner
+        gridliners = [a for a in self.artists if isinstance(a, Gridliner)]
+        if not gridliners:
+            return
+
         # Get the max ymax of all top labels
         top = -1
-        for gl in self._gridliners:
-            if gl.has_labels():
+        for gl in gridliners:
+            # Both top and geo labels can appear at the top of the axes
+            if gl.top_labels or gl.geo_labels:
+                # Make sure Gridliner is populated and up-to-date
+                gl._draw_gridliner(renderer=renderer)
                 for label in (gl.top_label_artists +
-                              gl.left_label_artists +
-                              gl.right_label_artists):
-                    # we skip bottom labels because they are usually
-                    # not at the top
+                              gl.geo_label_artists):
                     bb = label.get_tightbbox(renderer)
                     top = max(top, bb.ymax)
         if top < 0:
@@ -589,18 +581,11 @@ class GeoAxes(matplotlib.axes.Axes):
         self.dataLim.intervalx = self.projection.x_limits
         self.dataLim.intervaly = self.projection.y_limits
 
-    if mpl.__version__ >= '3.6':
-        def clear(self):
-            """Clear the current Axes and add boundary lines."""
-            result = super().clear()
-            self.__clear()
-            return result
-    else:
-        def cla(self):
-            """Clear the current Axes and add boundary lines."""
-            result = super().cla()
-            self.__clear()
-            return result
+    def clear(self):
+        """Clear the current Axes and add boundary lines."""
+        result = super().clear()
+        self.__clear()
+        return result
 
     def format_coord(self, x, y):
         """
@@ -654,7 +639,7 @@ class GeoAxes(matplotlib.axes.Axes):
         Parameters
         ----------
         rad_km
-            The radius in km of the the circles to be drawn.
+            The radius in km of the circles to be drawn.
         lons
             A numpy.ndarray, list or tuple of longitude values that
             locate the centre of each circle. Specifying more than one
@@ -724,7 +709,7 @@ class GeoAxes(matplotlib.axes.Axes):
         """
         # Instantiate an artist to draw the feature and add it to the axes.
         artist = feature_artist.FeatureArtist(feature, **kwargs)
-        return self.add_artist(artist)
+        return self.add_collection(artist)
 
     def add_geometries(self, geoms, crs, **kwargs):
         """
@@ -999,12 +984,13 @@ class GeoAxes(matplotlib.axes.Axes):
 
         return super().set_yticks(yticks, minor=minor)
 
-    def stock_img(self, name='ne_shaded'):
+    def stock_img(self, name='ne_shaded', **kwargs):
         """
         Add a standard image to the map.
 
-        Currently, the only (and default) option is a downsampled version of
-        the Natural Earth shaded relief raster.
+        Currently, the only (and default) option for image is a downsampled
+        version of the Natural Earth shaded relief raster. Other options
+        (e.g., alpha) will be passed to :func:`GeoAxes.imshow`.
 
         """
         if name == 'ne_shaded':
@@ -1014,7 +1000,8 @@ class GeoAxes(matplotlib.axes.Axes):
 
             return self.imshow(imread(fname), origin='upper',
                                transform=source_proj,
-                               extent=[-180, 180, -90, 90])
+                               extent=[-180, 180, -90, 90],
+                               **kwargs)
         else:
             raise ValueError('Unknown stock image %r.' % name)
 
@@ -1295,6 +1282,11 @@ class GeoAxes(matplotlib.axes.Axes):
 
         if (transform is None or transform == self.transData or
                 same_projection and inside_bounds):
+            if "regrid_shape" in kwargs:
+                warnings.warn("ignoring regrid_shape because it doesn't do anything "
+                              "when working in the same projection. To avoid this "
+                              "warning, remove the 'regrid_shape' keyword argument.")
+                kwargs.pop("regrid_shape")
             result = super().imshow(img, *args, **kwargs)
         else:
             extent = kwargs.pop('extent', None)
@@ -1368,7 +1360,7 @@ class GeoAxes(matplotlib.axes.Axes):
                   xformatter=None, yformatter=None, xlim=None, ylim=None,
                   rotate_labels=None, xlabel_style=None, ylabel_style=None,
                   labels_bbox_style=None, xpadding=5, ypadding=5,
-                  offset_angle=25, auto_update=False, formatter_kwargs=None,
+                  offset_angle=25, auto_update=None, formatter_kwargs=None,
                   **kwargs):
         """
         Automatically add gridlines to the axes, in the given coordinate
@@ -1473,9 +1465,13 @@ class GeoAxes(matplotlib.axes.Axes):
             a label must be flipped to be more readable.
             For example, a value of 10 makes a vertical top label to be
             flipped only at 100 degrees.
-        auto_update: bool
-            Whether to update the grilines and labels when the plot is
+        auto_update: bool, default=True
+            Whether to update the gridlines and labels when the plot is
             refreshed.
+
+            .. deprecated:: 0.23
+               In future the gridlines and labels will always be updated.
+
         formatter_kwargs: dict, optional
             Options passed to the default formatters.
             See :class:`~cartopy.mpl.ticker.LongitudeFormatter` and
@@ -1483,7 +1479,7 @@ class GeoAxes(matplotlib.axes.Axes):
 
         Keyword Parameters
         ------------------
-        **kwargs: dict
+        **kwargs:
             All other keywords control line properties.  These are passed
             through to :class:`matplotlib.collections.Collection`.
 
@@ -1502,7 +1498,7 @@ class GeoAxes(matplotlib.axes.Axes):
         the Y axis.
         """
         if crs is None:
-            crs = ccrs.PlateCarree()
+            crs = ccrs.PlateCarree(globe=self.projection.globe)
         from cartopy.mpl.gridliner import Gridliner
         gl = Gridliner(
             self, crs=crs, draw_labels=draw_labels, xlocator=xlocs,
@@ -1514,7 +1510,7 @@ class GeoAxes(matplotlib.axes.Axes):
             labels_bbox_style=labels_bbox_style,
             xpadding=xpadding, ypadding=ypadding, offset_angle=offset_angle,
             auto_update=auto_update, formatter_kwargs=formatter_kwargs)
-        self._gridliners.append(gl)
+        self.add_artist(gl)
         return gl
 
     def _gen_axes_patch(self):
@@ -1603,8 +1599,8 @@ class GeoAxes(matplotlib.axes.Axes):
         """
         result = super().contour(*args, **kwargs)
 
-        # We need to compute the dataLim correctly for contours.
-        if _MPL_VERSION.release[:2] < (3, 8):
+        if not _MPL_38:
+            # We need to compute the dataLim correctly for contours.
             bboxes = [col.get_datalim(self.transData)
                       for col in result.collections
                       if col.get_paths()]
@@ -1612,7 +1608,12 @@ class GeoAxes(matplotlib.axes.Axes):
                 extent = mtransforms.Bbox.union(bboxes)
                 self.update_datalim(extent.get_points())
         else:
-            self.update_datalim(result.get_datalim(self.transData))
+            # We need to compute the dataLim correctly for contours and set the
+            # artist's sticky edges to match.
+            datalim = result.get_datalim(self.transData)
+            self.update_datalim(datalim)
+            result.sticky_edges.x[:] = datalim.xmin, datalim.xmax
+            result.sticky_edges.y[:] = datalim.ymin, datalim.ymax
 
         self.autoscale_view()
 
@@ -1642,20 +1643,10 @@ class GeoAxes(matplotlib.axes.Axes):
             arguments X and Y must be provided and be 2-dimensional.
             The default is False, to compute the contours in data-space.
         """
-        t = kwargs.get('transform')
-        if isinstance(t, ccrs.Projection):
-            kwargs['transform'] = t = t._as_mpl_transform(self)
-        # Set flag to indicate correcting orientation of paths if not ccw
-        if isinstance(t, mtransforms.Transform):
-            for sub_trans, _ in t._iter_break_from_left_to_right():
-                if isinstance(sub_trans, InterProjectionTransform):
-                    if not hasattr(sub_trans, 'force_path_ccw'):
-                        sub_trans.force_path_ccw = True
-
         result = super().contourf(*args, **kwargs)
 
-        # We need to compute the dataLim correctly for contours.
-        if _MPL_VERSION.release[:2] < (3, 8):
+        if not _MPL_38:
+            # We need to compute the dataLim correctly for contours.
             bboxes = [col.get_datalim(self.transData)
                       for col in result.collections
                       if col.get_paths()]
@@ -1663,7 +1654,12 @@ class GeoAxes(matplotlib.axes.Axes):
                 extent = mtransforms.Bbox.union(bboxes)
                 self.update_datalim(extent.get_points())
         else:
-            self.update_datalim(result.get_datalim(self.transData))
+            # We need to compute the dataLim correctly for contours and set the
+            # artist's sticky edges to match.
+            datalim = result.get_datalim(self.transData)
+            self.update_datalim(datalim)
+            result.sticky_edges.x[:] = datalim.xmin, datalim.xmax
+            result.sticky_edges.y[:] = datalim.ymin, datalim.ymax
 
         self.autoscale_view()
 
@@ -1690,7 +1686,7 @@ class GeoAxes(matplotlib.axes.Axes):
                 kwargs['transform'].source_projection.is_geodetic()):
             raise ValueError('Cartopy cannot currently do spherical '
                              'scatter. The source CRS cannot be a '
-                             'geodetic, consider using the cyllindrical form '
+                             'geodetic, consider using the cylindrical form '
                              '(PlateCarree or RotatedPole).')
 
         result = super().scatter(*args, **kwargs)
@@ -1794,8 +1790,8 @@ class GeoAxes(matplotlib.axes.Axes):
         the data coordinates before passing on to Matplotlib.
         """
         default_shading = mpl.rcParams.get('pcolor.shading')
-        if not (kwargs.get('shading', default_shading) in
-                ('nearest', 'auto') and len(args) == 3 and
+        shading = kwargs.get('shading') or default_shading
+        if not (shading in ('nearest', 'auto') and len(args) == 3 and
                 getattr(kwargs.get('transform'), '_wrappable', False)):
             return args, kwargs
 
@@ -1911,7 +1907,7 @@ class GeoAxes(matplotlib.axes.Axes):
                           "It is recommended to remove the wrap manually "
                           "before calling pcolormesh.")
             # With gouraud shading, we actually want an (Ny, Nx) shaped mask
-            gmask = np.zeros(data_shape, dtype=bool)
+            gmask = np.zeros((data_shape[0], data_shape[1]), dtype=bool)
             # If any of the cells were wrapped, apply it to all 4 corners
             gmask[:-1, :-1] |= mask
             gmask[1:, :-1] |= mask
@@ -1952,7 +1948,7 @@ class GeoAxes(matplotlib.axes.Axes):
         # masked, so this will only draw a limited subset of
         # polygons that were actually wrapped.
 
-        if _MPL_VERSION.release[:2] < (3, 8):
+        if not _MPL_38:
             # We will add the original data mask in later to
             # make sure that set_array can work in future
             # calls on the proper sized array inputs.
@@ -2306,13 +2302,12 @@ GeoAxesSubplot = matplotlib.axes.subplot_class_factory(GeoAxes)
 GeoAxesSubplot.__module__ = GeoAxes.__module__
 
 
-def _trigger_patch_reclip(event):
+def _trigger_patch_reclip(axes):
     """
     Define an event callback for a GeoAxes which forces the background patch to
     be re-clipped next time it is drawn.
 
     """
-    axes = event.axes
     # trigger the outline and background patches to be re-clipped
     axes.spines['geo'].stale = True
     axes.patch.stale = True
