@@ -1,16 +1,13 @@
-# Copyright Cartopy Contributors
+# Copyright Crown and Cartopy Contributors
 #
-# This file is part of Cartopy and is released under the LGPL license.
-# See COPYING and COPYING.LESSER in the root of the repository for full
-# licensing details.
+# This file is part of Cartopy and is released under the BSD 3-clause license.
+# See LICENSE in the root of the repository for full licensing details.
 
-import os
 import types
 
-import numpy as np
-import matplotlib.pyplot as plt
-import matplotlib.cm as cm
 import matplotlib.colors as colors
+import matplotlib.pyplot as plt
+import numpy as np
 from PIL import Image
 import pytest
 import shapely.geometry as sgeom
@@ -18,16 +15,18 @@ import shapely.geometry as sgeom
 from cartopy import config
 import cartopy.crs as ccrs
 import cartopy.io.img_tiles as cimgt
-
-from cartopy.tests.mpl import ImageTesting
+from cartopy.tests.conftest import _HAS_PYKDTREE_OR_SCIPY
 import cartopy.tests.test_img_tiles as ctest_tiles
 
 
-NATURAL_EARTH_IMG = os.path.join(config["repo_data_dir"],
-                                 'raster', 'natural_earth',
-                                 '50-natural-earth-1-downsampled.png')
-REGIONAL_IMG = os.path.join(config['repo_data_dir'], 'raster', 'sample',
-                            'Miriam.A2012270.2050.2km.jpg')
+if not _HAS_PYKDTREE_OR_SCIPY:
+    pytest.skip('pykdtree or scipy is required', allow_module_level=True)
+
+
+NATURAL_EARTH_IMG = (config["repo_data_dir"] / 'raster' / 'natural_earth'
+                     / '50-natural-earth-1-downsampled.png')
+REGIONAL_IMG = (config['repo_data_dir'] / 'raster' / 'sample'
+                / 'Miriam.A2012270.2050.2km.jpg')
 
 
 # We have an exceptionally large tolerance for the web_tiles test.
@@ -35,7 +34,7 @@ REGIONAL_IMG = os.path.join(config['repo_data_dir'], 'raster', 'sample',
 # care that it is putting images onto the map which are roughly correct.
 @pytest.mark.natural_earth
 @pytest.mark.network
-@ImageTesting(['web_tiles'], tolerance=5.91)
+@pytest.mark.mpl_image_compare(filename='web_tiles.png', tolerance=5.91)
 def test_web_tiles():
     extent = [-15, 0.1, 50, 60]
     target_domain = sgeom.Polygon([[extent[0], extent[1]],
@@ -44,8 +43,9 @@ def test_web_tiles():
                                    [extent[0], extent[3]],
                                    [extent[0], extent[1]]])
     map_prj = cimgt.GoogleTiles().crs
+    fig = plt.figure()
 
-    ax = plt.subplot(2, 2, 1, projection=map_prj)
+    ax = fig.add_subplot(2, 2, 1, projection=map_prj)
     gt = cimgt.GoogleTiles()
     gt._image_url = types.MethodType(ctest_tiles.GOOGLE_IMAGE_URL_REPLACEMENT,
                                      gt)
@@ -54,24 +54,26 @@ def test_web_tiles():
               interpolation='bilinear', origin=origin)
     ax.coastlines(color='white')
 
-    ax = plt.subplot(2, 2, 2, projection=map_prj)
+    ax = fig.add_subplot(2, 2, 2, projection=map_prj)
     qt = cimgt.QuadtreeTiles()
     img, extent, origin = qt.image_for_domain(target_domain, 1)
     ax.imshow(np.array(img), extent=extent, transform=qt.crs,
               interpolation='bilinear', origin=origin)
     ax.coastlines(color='white')
 
-    ax = plt.subplot(2, 2, 3, projection=map_prj)
+    ax = fig.add_subplot(2, 2, 3, projection=map_prj)
     osm = cimgt.OSM()
     img, extent, origin = osm.image_for_domain(target_domain, 1)
     ax.imshow(np.array(img), extent=extent, transform=osm.crs,
               interpolation='bilinear', origin=origin)
     ax.coastlines()
 
+    return fig
+
 
 @pytest.mark.natural_earth
 @pytest.mark.network
-@ImageTesting(['image_merge'], tolerance=0.01)
+@pytest.mark.mpl_image_compare(filename='image_merge.png', tolerance=0.03)
 def test_image_merge():
     # tests the basic image merging functionality
     tiles = []
@@ -94,10 +96,12 @@ def test_image_merge():
     ax = plt.axes(projection=gt.crs)
     ax.set_global()
     ax.coastlines()
-    plt.imshow(img, origin=origin, extent=extent, alpha=0.5)
+    ax.imshow(img, origin=origin, extent=extent, alpha=0.5)
+
+    return ax.figure
 
 
-@ImageTesting(['imshow_natural_earth_ortho'], tolerance=0.7)
+@pytest.mark.mpl_image_compare(filename='imshow_natural_earth_ortho.png')
 def test_imshow():
     source_proj = ccrs.PlateCarree()
     img = plt.imread(NATURAL_EARTH_IMG)
@@ -107,10 +111,12 @@ def test_imshow():
     ax = plt.axes(projection=ccrs.Orthographic())
     ax.imshow(img, transform=source_proj,
               extent=[-180, 180, -90, 90])
+    return ax.figure
 
 
 @pytest.mark.natural_earth
-@ImageTesting(['imshow_regional_projected'], tolerance=0.8)
+@pytest.mark.mpl_image_compare(filename='imshow_regional_projected.png',
+                               tolerance=0.8)
 def test_imshow_projected():
     source_proj = ccrs.PlateCarree()
     img_extent = (-120.67660000000001, -106.32104523100001,
@@ -120,6 +126,7 @@ def test_imshow_projected():
     ax.set_extent(img_extent, crs=source_proj)
     ax.coastlines(resolution='50m')
     ax.imshow(img, extent=img_extent, transform=source_proj)
+    return ax.figure
 
 
 def test_imshow_wrapping():
@@ -132,11 +139,21 @@ def test_imshow_wrapping():
     assert ax.get_xlim() == (-180, 180)
 
 
+def test_imshow_arguments():
+    """Smoke test for imshow argument passing in the fast-path"""
+    ax = plt.axes(projection=ccrs.PlateCarree())
+    # Set the regrid_shape parameter to ensure it isn't passed to Axes.imshow()
+    # in the fast-path call to super()
+    with pytest.warns(UserWarning, match="ignoring regrid_shape"):
+        ax.imshow(np.random.random((10, 10)), transform=ccrs.PlateCarree(),
+              extent=(-180, 180, -90, 90), regrid_shape=500)
+
+
 def test_imshow_rgba():
     # tests that the alpha of a RGBA array passed to imshow is set to 0
     # instead of masked
-    z = np.ones((100, 100))*0.5
-    cmap = cm.get_cmap()
+    z = np.full((100, 100), 0.5)
+    cmap = plt.get_cmap()
     norm = colors.Normalize(vmin=0, vmax=1)
     z1 = cmap(norm(z))
     plt_crs = ccrs.LambertAzimuthalEqualArea()
@@ -145,41 +162,59 @@ def test_imshow_rgba():
     ax.set_extent([-30, -20, 60, 70], crs=latlon_crs)
     img = ax.imshow(z1, extent=[-26, -24, 64, 66], transform=latlon_crs)
     assert sum(img.get_array().data[:, 0, 3]) == 0
-    plt.close()
+
+
+def test_imshow_rgba_alpha():
+    # test that alpha channel from RGBA is not skipped
+    dy, dx = (3, 4)
+
+    ax = plt.axes(projection=ccrs.Orthographic(-120, 45))
+
+    # Create RGBA Image with random data and linspace alpha
+    RGBA = np.linspace(0, 255 * 31, dx * dy * 4,
+                       dtype=np.uint8).reshape((dy, dx, 4))
+
+    alpha = np.array([0, 85, 170, 255])
+    RGBA[:, :, 3] = alpha
+
+    img = ax.imshow(RGBA, transform=ccrs.PlateCarree())
+    assert np.all(np.unique(img.get_array().data[:, :, 3]) == alpha)
 
 
 def test_imshow_rgb():
     # tests that the alpha of a RGB array passed to imshow is set to 0
     # instead of masked
-    z = np.ones((100, 100, 3))*0.5
+    z = np.full((100, 100, 3), 0.5)
     plt_crs = ccrs.LambertAzimuthalEqualArea()
     latlon_crs = ccrs.PlateCarree()
     ax = plt.axes(projection=plt_crs)
     ax.set_extent([-30, -20, 60, 70], crs=latlon_crs)
     img = ax.imshow(z, extent=[-26, -24, 64, 66], transform=latlon_crs)
     assert sum(img.get_array().data[:, 0, 3]) == 0
-    plt.close()
 
 
-@ImageTesting(['imshow_natural_earth_ortho'], tolerance=0.7)
+@pytest.mark.mpl_image_compare(filename='imshow_natural_earth_ortho.png')
 def test_stock_img():
     ax = plt.axes(projection=ccrs.Orthographic())
     ax.stock_img()
+    return ax.figure
 
 
-@ImageTesting(['imshow_natural_earth_ortho'], tolerance=0.7)
+@pytest.mark.mpl_image_compare(filename='imshow_natural_earth_ortho.png')
 def test_pil_Image():
     img = Image.open(NATURAL_EARTH_IMG)
     source_proj = ccrs.PlateCarree()
     ax = plt.axes(projection=ccrs.Orthographic())
     ax.imshow(img, transform=source_proj,
               extent=[-180, 180, -90, 90])
+    return ax.figure
 
 
-@ImageTesting(['imshow_natural_earth_ortho'])
+@pytest.mark.mpl_image_compare(filename='imshow_natural_earth_ortho.png')
 def test_background_img():
     ax = plt.axes(projection=ccrs.Orthographic())
     ax.background_img(name='ne_shaded', resolution='low')
+    return ax.figure
 
 
 def test_alpha_2d_warp():
@@ -194,9 +229,7 @@ def test_alpha_2d_warp():
     fake_alphas = np.zeros(fake_data.shape)
     image = ax.imshow(fake_data, extent=coords, transform=latlon_crs,
                       alpha=fake_alphas)
-    plt.close()
     image_data = image.get_array()
     image_alpha = image.get_alpha()
 
     assert image_data.shape == image_alpha.shape
-    plt.close()
