@@ -1,14 +1,21 @@
-# Copyright Cartopy Contributors
+# Copyright Crown and Cartopy Contributors
 #
-# This file is part of Cartopy and is released under the LGPL license.
-# See COPYING and COPYING.LESSER in the root of the repository for full
-# licensing details.
+# This file is part of Cartopy and is released under the BSD 3-clause license.
+# See LICENSE in the root of the repository for full licensing details.
 
 import numpy as np
 from numpy.testing import assert_array_equal
 import pytest
-import scipy.spatial
 
+from cartopy.tests.conftest import (
+    _HAS_PYKDTREE_OR_SCIPY,
+    requires_pykdtree,
+    requires_scipy,
+)
+
+
+if not _HAS_PYKDTREE_OR_SCIPY:
+    pytest.skip("pykdtree or scipy are required", allow_module_level=True)
 import cartopy.crs as ccrs
 import cartopy.img_transform as img_trans
 
@@ -113,7 +120,8 @@ def test_gridding_data_outside_projection():
 
 @pytest.mark.parametrize("target_prj",
                          (ccrs.Mollweide(), ccrs.Orthographic()))
-@pytest.mark.parametrize("use_scipy", (True, False))
+@pytest.mark.parametrize("use_scipy", (pytest.param(True, marks=requires_scipy),
+                                       pytest.param(False, marks=requires_pykdtree)))
 def test_regridding_with_invalid_extent(target_prj, use_scipy, monkeypatch):
     # tests that when a valid extent results in invalid points in the
     # transformed coordinates, the regridding does not error.
@@ -128,6 +136,7 @@ def test_regridding_with_invalid_extent(target_prj, use_scipy, monkeypatch):
 
     if use_scipy:
         monkeypatch.setattr(img_trans, "_is_pykdtree", False)
+        import scipy.spatial
         monkeypatch.setattr(img_trans, "_kdtreeClass", scipy.spatial.cKDTree)
     _ = img_trans.regrid(data, lons, lats, data_trans, target_prj,
                          target_x, target_y)
